#ifndef H_CDW_READ_DISC
#define H_CDW_READ_DISC

#include "main.h"
#include "cdw_disc.h"

cdw_rv_t cdw_read_disc(void);

/* used by md5sum code */
bool cdw_read_disc_is_proper(cdw_disc_t *disc);

#endif /* H_CDW_READ_DISC */
